/*   
 * Copyright 2007 Sun Microsystems, Inc.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package com.sun.syndication.propono.atom.client;

import com.sun.syndication.feed.atom.Content;
import java.util.Iterator;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import org.apache.commons.httpclient.HttpClient;
import org.apache.commons.httpclient.NameValuePair;
import org.apache.commons.httpclient.methods.PostMethod;

/**
 * Simple APP test designed to run against Blogger.com.
 */
public class BloggerDotComTest extends TestCase {
    
    private String loginEndpoint = "https://www.google.com/accounts/ClientLogin";
    private String endpoint      = "http://www.blogger.com/feeds/BLOGID/posts/default";
    private String email         = "USERNAME@gmail.com";
    private String password      = "PASSWORD";
    private String service       = "blogger";
    private String source        = "ROME-Propono-0.5";
    private String accountType   = "GOOGLE";
    
    public BloggerDotComTest(String testName) {
        super(testName);
    }

    protected void setUp() throws Exception {
    }

    protected void tearDown() throws Exception {
    }

    public static Test suite() {
        TestSuite suite = new TestSuite(BloggerDotComTest.class);        
        return suite;
    }

    /**
     * Verify that server returns service document containing workspaces containing collections.
     */
    public void testGetEntries() throws Exception { 
        
        HttpClient httpClient = new HttpClient(); 
                
        // no auth necessary for iterating through entries
        ClientCollection col = AtomClientFactory.getCollection(endpoint);
        assertNotNull(col);
        int count = 0;
        for (Iterator it = col.getEntries(); it.hasNext();) {
            ClientEntry entry = (ClientEntry) it.next();
            assertNotNull(entry);
            count++;
        }
        assertTrue(count > 0);
        
        // auth is necesary for posting 
        PostMethod method = new PostMethod(loginEndpoint);  
        NameValuePair[] data = {
          new NameValuePair("Email", email),
          new NameValuePair("Passwd", password),
          new NameValuePair("accountType", accountType),
          new NameValuePair("service", service),
          new NameValuePair("source", source)
        };
        method.setRequestBody(data);
        httpClient.executeMethod(method);  
        
        String responseBody = method.getResponseBodyAsString();
        int authIndex = responseBody.indexOf("Auth=");
        assertTrue(authIndex != -1);
        
        String authString = "GoogleLogin auth=" 
                + responseBody.trim().substring(authIndex + 5);

        col = AtomClientFactory.getCollection(endpoint, authString);
        ClientEntry p1 = col.createEntry();
        p1.setTitle("Propono post");
        Content c = new Content();
        c.setValue("This is content from ROME Propono");
        p1.setContent(c);
        col.addEntry(p1);
        
        ClientEntry p2 = col.getEntry(p1.getEditURI());
        assertNotNull(p2);
    }
}


